==> haskell-conduit-combinators-1.0.3.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-combinators/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.3.1
id: conduit-combinators-1.0.3.1-b01280900630c041853dd47fc80a4e85
key: condu_9JSugp5oZ5n2cjlzGHrNBx
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/conduit-combinators
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
hs-libraries: HSconduit-combinators-1.0.3.1-9JSugp5oZ5n2cjlzGHrNBx
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    chunked-data-0.2.0-7f7c713e155b288dfc1128b9e7ed1b75
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    conduit-extra-1.1.9.3-79f96334aec0357c74e6e80c98ebd34c
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mono-traversable-0.10.1.1-3becc6471509e2f7471fef0fd512f087
    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    void-0.7.1-662e5f28c19568c0aec0b2de7532ac34
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-combinators-1.0.3.1-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-combinators/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-combinators
version: 1.0.3.1
id: conduit-combinators-1.0.3.1-dee0b8ffe69f92493a3f0964656aeb3e
key: condu_3KmvgdgKXtN1cwBWWKMYOO
license: MIT
maintainer: michael@snoyman.com
homepage: https://github.com/fpco/conduit-combinators
synopsis: Commonly used conduit functions, for both chunked and unchunked data
description:
    Provides a replacement for Data.Conduit.List, as well as a convenient Conduit module.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Conduit Data.Conduit.Combinators Data.Conduit.Combinators.Internal
    Data.Conduit.Combinators.Stream
hidden-modules: Data.Conduit.Combinators.Unqualified
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-combinators-1.0.3.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-combinators-1.0.3.1
hs-libraries: HSconduit-combinators-1.0.3.1-3KmvgdgKXtN1cwBWWKMYOO
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base16-bytestring-0.1.1.6-2ce49c0fdad8d57abae997bf0287241a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    chunked-data-0.2.0-7f3077a014828f2c9ef957d0fe9eb847
    conduit-1.2.6.2-e9736ac2851958c9940f374454cdc4fe
    conduit-extra-1.1.10-5c65857e3dfbc5cf563dbabcd22bcb07
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    mono-traversable-0.10.1.1-f79bc7831a1f09825852f2c78d51d1f8
    mwc-random-0.13.3.2-98468153c4310cd751df6539413688b8
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    resourcet-1.1.7.2-b95e5d14f30eaa21587bc62eeb9aed0c
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
    void-0.7.1-5ad9ec6793ffb57ac26a200023a4290d
haddock-interfaces: /usr/share/doc/haskell-conduit-combinators/html/conduit-combinators.haddock
haddock-html: /usr/share/doc/haskell-conduit-combinators/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
